@@ -1,15 +1,19 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+# 3rd party imports
+import numpy as np
+import xarray as xr
+
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
-def eis_omni(eis_allt):
+def eis_omni(eis_allt, method: str = "mean"):
     r"""Calculates the omni-directional flux for all 6 telescopes.
 
     Parameters
@@ -45,17 +49,26 @@ def eis_omni(eis_allt):
 
     """
 
+    assert method.lower() in ["mean", "sum"]
+
     scopes = list(filter(lambda x: x[0] == "t", eis_allt))
 
-    flux_omni = None
+    flux_omni = np.zeros_like(eis_allt[scopes[0]].data)
 
     for scope in scopes:
         try:
-            flux_omni += eis_allt[scope].copy()
+            flux_omni += eis_allt[scope].data.copy()
         except TypeError:
-            flux_omni = eis_allt[scope].copy()
+            flux_omni = eis_allt[scope].data.copy()
 
-    flux_omni.data /= len(scopes)
-    flux_omni.name = "flux_omni"
+    if method.lower() == "mean":
+        flux_omni /= len(scopes)
+
+    # Get dimensions, coordinates and attributes based on first telescope
+    dims = eis_allt[scopes[0]].dims
+    coords = [eis_allt[scopes[0]][k] for k in dims]
+    attrs = eis_allt[scopes[0]].attrs
+
+    flux_omni = xr.DataArray(flux_omni, coords=coords, dims=dims, attrs=attrs)
 
     return flux_omni
