@@ -4,14 +4,13 @@
 # 3rd party imports
 import numpy as np
 import xarray as xr
-
 from cdflib import cdfread
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -36,7 +35,11 @@ def get_variable(file_path, cdf_name):
         var_data = file.varget(cdf_name)
         var_atts = file.varattsget(cdf_name)
 
-    out = xr.DataArray(var_data, coords=[np.arange(len(var_data))], dims=["x"],
-                       attrs=var_atts)
+    out = xr.DataArray(
+        var_data,
+        coords=[np.arange(len(var_data))],
+        dims=["x"],
+        attrs=var_atts,
+    )
 
     return out
