@@ -2,37 +2,76 @@
 # -*- coding: utf-8 -*-
 
 # Built-in imports
-import bisect
+import logging
 import multiprocessing as mp
 
 # 3rd party imports
 import numpy as np
 import xarray as xr
-
 from scipy import constants
 
 # Local imports
-from ..pyrf import resample, ts_scalar, ts_vec_xyz, ts_tensor_xyz
+from ..pyrf.resample import resample
+from ..pyrf.ts_scalar import ts_scalar
+from ..pyrf.ts_tensor_xyz import ts_tensor_xyz
+from ..pyrf.ts_vec_xyz import ts_vec_xyz
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
+logging.captureWarnings(True)
+logging.basicConfig(
+    format="[%(asctime)s] %(levelname)s: %(message)s",
+    datefmt="%d-%b-%y %H:%M:%S",
+    level=logging.INFO,
+)
+
 
 # noinspection PyUnboundLocalVariable
 def _moms(time_idx, arguments):
     if len(arguments) > 13:
-        [is_brst_data, flag_same_e, flag_de, step_table, energy0, delta_v0,
-         energy1, delta_v1, q_e, sc_pot, p_mass, flag_inner_electron,
-         w_inner_electron, phi_tr, theta_k, int_energies, vdf, delta_ang] = \
-            arguments
+        [
+            is_brst_data,
+            flag_same_e,
+            flag_de,
+            step_table,
+            energy0,
+            delta_v0,
+            energy1,
+            delta_v1,
+            q_e,
+            sc_pot,
+            p_mass,
+            flag_inner_electron,
+            w_inner_electron,
+            phi_tr,
+            theta_k,
+            int_energies,
+            vdf,
+            delta_ang,
+        ] = arguments
     else:
-        [is_brst_data, flag_same_e, flag_de, energy, delta_v, q_e, sc_pot,
-         p_mass, flag_inner_electron, w_inner_electron, phi_tr, theta_k,
-         int_energies, vdf, delta_ang] = arguments
+        [
+            is_brst_data,
+            flag_same_e,
+            flag_de,
+            energy,
+            delta_v,
+            q_e,
+            sc_pot,
+            p_mass,
+            flag_inner_electron,
+            w_inner_electron,
+            phi_tr,
+            theta_k,
+            int_energies,
+            vdf,
+            delta_ang,
+        ] = arguments
 
     if is_brst_data:
         if not flag_same_e or not flag_de:
@@ -43,10 +82,12 @@ def _moms(time_idx, arguments):
                 energy = energy1
                 delta_v = delta_v1
 
-    velocity = np.real(np.sqrt(2 * q_e * (energy
-                                          - sc_pot.data[time_idx]) / p_mass))
-    velocity[energy - sc_pot.data[time_idx]
-             - flag_inner_electron * w_inner_electron < 0] = 0
+    velocity = np.real(
+        np.sqrt(2 * q_e * (energy - sc_pot.data[time_idx]) / p_mass),
+    )
+    velocity[
+        energy - sc_pot.data[time_idx] - flag_inner_electron * w_inner_electron < 0
+    ] = 0
 
     if is_brst_data:
         phi_j = phi_tr[time_idx, :]
@@ -142,7 +183,7 @@ def psd_moments(vdf, sc_pot, **kwargs):
         Time series of the spacecraft potential.
 
     Returns
-    --------
+    -------
     n_psd : xarray.DataArray
         Time series of the number density (1rst moment).
     v_psd : xarray.DataArray
@@ -168,11 +209,11 @@ def psd_moments(vdf, sc_pot, **kwargs):
     en_channels : array_like
         Set energy channels to integrate over [min max]; min and max between
         must be between 1 and 32.
-    partial_moments : ndarray or xarray.DataArray
-        Use a binary array (or DataArray) (pmomsarr) to select which psd
-        points are used in the moments calculation. pmomsarr must be a
-        binary array (1s and 0s, 1s correspond to points used). Array (or
-        data of Dataarray) must be the same size as vdf.data.
+    partial_moments : numpy.ndarray or xarray.DataArray
+        Use a binary array to select which psd points are used in the moments
+        calculation. `partial_moments` must be a binary array (1s and 0s,
+        1s correspond to points used). Array (or data of Dataarray) must be the same
+        size as vdf.data.
     inner_electron : {"on", "off"}
         inner_electrontron potential for electron moments.
 
@@ -207,14 +248,14 @@ def psd_moments(vdf, sc_pot, **kwargs):
     vdf.data.data *= 1e12
 
     # Check if data is fast or burst resolution
-    field_name = vdf.attrs["FIELDNAM"]
+    field_name = vdf.data.attrs["FIELDNAM"]
 
     if "brst" in field_name:
         is_brst_data = True
-        print("notice : Burst resolution data is used")
-    elif "brst" in field_name:
+        logging.info("Burst resolution data is used")
+    elif "fast" in field_name:
         is_brst_data = False
-        print("notice : Fast resolution data is used")
+        logging.info("Fast resolution data is used")
     else:
         raise TypeError("Could not identify if data is fast or burst.")
 
@@ -247,24 +288,28 @@ def psd_moments(vdf, sc_pot, **kwargs):
     sc_pot = resample(sc_pot, vdf.time)
 
     if "energy_range" in kwargs:
-        if isinstance(kwargs["energy_range"], (list, np.ndarray)) and \
-                len(kwargs["energy_range"]) == 2:
+        if (
+            isinstance(kwargs["energy_range"], (list, np.ndarray))
+            and len(kwargs["energy_range"]) == 2
+        ):
             if not is_brst_data:
                 energy0 = energy
 
-            e_min_max = kwargs["energy_range"]
-            start_e = bisect.bisect_left(energy0, e_min_max[0])
-            stop_e = bisect.bisect_left(energy0, e_min_max[1])
+            # e_min_max = kwargs["energy_range"]
+            # start_e = bisect.bisect_left(energy0, e_min_max[0])
+            # stop_e = bisect.bisect_left(energy0, e_min_max[1])
 
-            print("notice : Using partial energy range")
+            logging.info("Using partial energy range")
 
     if "no_sc_pot" in kwargs:
         if isinstance(kwargs["no_sc_pot"], bool) and not kwargs["no_sc_pot"]:
             sc_pot.data = np.zeros(sc_pot.shape)
-            print("notice : Setting spacecraft potential to zero")
+            logging.info("Setting spacecraft potential to zero")
 
-    int_energies = np.arange(kwargs.get("en_channels", [0, 32])[0],
-                             kwargs.get("en_channels", [0, 32])[1])
+    int_energies = np.arange(
+        kwargs.get("en_channels", [0, 32])[0],
+        kwargs.get("en_channels", [0, 32])[1],
+    )
 
     if "partial_moments" in kwargs:
         partial_moments = kwargs["partial_moments"]
@@ -273,26 +318,38 @@ def psd_moments(vdf, sc_pot, **kwargs):
 
         # Check size of partial_moments
         if partial_moments.shape == vdf.data.shape:
-            sum_ones = np.sum(np.sum(np.sum(np.sum(partial_moments, axis=-1),
-                                            axis=-1), axis=-1), axis=-1)
+            sum_ones = np.sum(
+                np.sum(
+                    np.sum(np.sum(partial_moments, axis=-1), axis=-1),
+                    axis=-1,
+                ),
+                axis=-1,
+            )
             sum_zeros = np.sum(
-                np.sum(np.sum(np.sum(-partial_moments + 1, axis=-1), axis=-1),
-                       axis=-1), axis=-1)
+                np.sum(
+                    np.sum(np.sum(-partial_moments + 1, axis=-1), axis=-1),
+                    axis=-1,
+                ),
+                axis=-1,
+            )
 
             if (sum_ones + sum_zeros) == vdf.data.size:
-                print("notice : partial_moments is correct. Partial moments "
-                      "will be calculated")
+                logging.info(
+                    "partial_moments is correct. Partial moments will be calculated"
+                )
                 vdf.data = vdf.data * partial_moments
             else:
-                print("notice : All values are not ones and zeros in "
-                      "partial_moments. Full " +
-                      "moments will be calculated")
+                logging.info(
+                    "All values are not ones and zeros in partial_moments. "
+                    "Full moments will be calculated"
+                )
         else:
-            print("notice : Size of partial_moments is wrong. Full moments "
-                  "will be calculated")
+            logging.info(
+                "Size of partial_moments is wrong. Full moments will be calculated"
+            )
 
     tmp_ = kwargs.get("inner_electron", "")
-    flag_inner_electron = (tmp_ == "on" and particle_type[0] == "e")
+    flag_inner_electron = tmp_ == "on" and particle_type[0] == "e"
 
     # Define constants
     q_e = constants.elementary_charge
@@ -300,11 +357,11 @@ def psd_moments(vdf, sc_pot, **kwargs):
 
     if particle_type[0] == "e":
         p_mass = constants.electron_mass
-        print("notice : Particles are electrons")
+        logging.info("Particles are electrons")
     elif particle_type[0] == "i":
         p_mass = constants.proton_mass
-        sc_pot.data = -1. * sc_pot.data
-        print("notice : Particles are ions")
+        sc_pot.data = -1.0 * sc_pot.data
+        logging.info("Particles are ions")
     else:
         raise ValueError("Could not identify the particle type")
 
@@ -385,27 +442,55 @@ def psd_moments(vdf, sc_pot, **kwargs):
     theta_k = theta_k.data[np.newaxis, :]
 
     if is_brst_data:
-        args_ = (is_brst_data, flag_same_e, flag_de, step_table, energy0,
-                 delta_v0, energy1, delta_v1, q_e, sc_pot.data, p_mass,
-                 flag_inner_electron, w_inner_electron, phi_tr.data,
-                 theta_k, int_energies, vdf.data.data, delta_ang)
+        args_ = (
+            is_brst_data,
+            flag_same_e,
+            flag_de,
+            step_table,
+            energy0,
+            delta_v0,
+            energy1,
+            delta_v1,
+            q_e,
+            sc_pot.data,
+            p_mass,
+            flag_inner_electron,
+            w_inner_electron,
+            phi_tr.data,
+            theta_k,
+            int_energies,
+            vdf.data.data,
+            delta_ang,
+        )
     else:
-        args_ = (is_brst_data, flag_same_e, flag_de, energy, delta_v, q_e,
-                 sc_pot.data, p_mass, flag_inner_electron, w_inner_electron,
-                 phi_tr.data, theta_k, int_energies, vdf.data, delta_ang)
+        args_ = (
+            is_brst_data,
+            flag_same_e,
+            flag_de,
+            energy,
+            delta_v,
+            q_e,
+            sc_pot.data,
+            p_mass,
+            flag_inner_electron,
+            w_inner_electron,
+            phi_tr.data,
+            theta_k,
+            int_energies,
+            vdf.data,
+            delta_ang,
+        )
 
-    pool = mp.Pool(mp.cpu_count())
-    res = pool.starmap(_moms, [(nt, args_) for nt in range(len(vdf.time))])
-    out = np.vstack(res)
+    with mp.Pool(mp.cpu_count()) as pool:
+        res = pool.starmap(_moms, [(nt, args_) for nt in range(len(vdf.time))])
+        out = np.vstack(res)
 
-    n_psd = np.array(out[:, 0], dtype="float")
-    v_psd = np.vstack(out[:, 1][:])
-    p_psd = np.vstack(out[:, 2][:])
-    p_psd = np.reshape(p_psd, (len(n_psd), 3, 3))
-    h_psd = np.vstack(out[:, 3][:])
-    p2_psd = np.zeros((len(vdf.time), 3, 3))
-
-    pool.close()
+        n_psd = np.array(out[:, 0], dtype="float")
+        v_psd = np.vstack(out[:, 1][:])
+        p_psd = np.vstack(out[:, 2][:])
+        p_psd = np.reshape(p_psd, (len(n_psd), 3, 3))
+        h_psd = np.vstack(out[:, 3][:])
+        p2_psd = np.zeros((len(vdf.time), 3, 3))
 
     # Compute moments in SI units
     p_psd *= p_mass
