@@ -7,9 +7,9 @@ import xarray as xr
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -34,9 +34,12 @@ def spectr_to_dataset(spectr):
 
     data = spectr.data
 
-    out_dict = {"data": (["time", "idx0"], data),
-                "energy": (["time", "idx0"], energy),
-                "time": time, "idx0": np.arange(energy.shape[1])}
+    out_dict = {
+        "data": (["time", "idx0"], data),
+        "energy": (["time", "idx0"], energy),
+        "time": time,
+        "idx0": np.arange(energy.shape[1]),
+    }
 
     out = xr.Dataset(out_dict)
 
