@@ -3,12 +3,13 @@
 
 # 3rd party imports
 import numpy as np
+import xarray as xr
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -17,7 +18,7 @@ def calc_fs(inp):
 
     Parameters
     ----------
-    inp : xarray.DataArray
+    inp : xarray.DataArray or xarray.Dataset
         Time series of the input variable.
 
     Returns
@@ -27,6 +28,9 @@ def calc_fs(inp):
 
     """
 
-    out = 1 / (np.median(np.diff(inp.time.data)).astype(float) * 1e-9)
+    message = "Input must be a time series"
+    assert isinstance(inp, (xr.Dataset, xr.DataArray)), message
+
+    out = 1 / (np.median(np.diff(inp.time.data)).astype(np.float64) * 1e-9)
 
     return out
