@@ -6,9 +6,9 @@ import numpy as np
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -21,7 +21,7 @@ def cart2sph(x, y, z):
         \beta = \arccos \left( \frac{z}{r} \right) \\
         r = \sqrt{x^2 + y^2 + z^2}
 
-    with :math:`\alpha \in [0, 2\pi), \beta \in [0, \pi], r \geq 0`
+    with :math:`\alpha \in [0, 2\pi], \beta \in [0, \pi], r \geq 0`
 
     Parameters
     ----------
