@@ -6,9 +6,9 @@ from datetime import datetime
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -33,19 +33,27 @@ def date_str(tint, fmt: int = 1):
 
     """
 
-    start_time = datetime.strptime(tint[0], '%Y-%m-%dT%H:%M:%S.%f')
-    end_time = datetime.strptime(tint[1], '%Y-%m-%dT%H:%M:%S.%f')
+    start_time = datetime.strptime(tint[0], "%Y-%m-%dT%H:%M:%S.%f")
+    end_time = datetime.strptime(tint[1], "%Y-%m-%dT%H:%M:%S.%f")
 
     if fmt == 1:
         out = start_time.strftime("%Y%m%d_%H%M")
     elif fmt == 2:
         out = start_time.strftime("%y%m%d%H%M%S")
     elif fmt == 3:
-        out = "_".join([start_time.strftime("%Y%m%d_%H%M%S"),
-                        end_time.strftime("%H%M%S")])
+        out = "_".join(
+            [
+                start_time.strftime("%Y%m%d_%H%M%S"),
+                end_time.strftime("%H%M%S"),
+            ],
+        )
     elif fmt == 4:
-        out = "_".join([start_time.strftime("%Y%m%d_%H%M%S"),
-                        end_time.strftime("%Y%m%d_%H%M%S")])
+        out = "_".join(
+            [
+                start_time.strftime("%Y%m%d_%H%M%S"),
+                end_time.strftime("%Y%m%d_%H%M%S"),
+            ],
+        )
     else:
         raise ValueError("Unknown format")
 
