@@ -4,14 +4,13 @@
 # 3rd party imports
 import numpy as np
 import xarray as xr
-
 from scipy.stats import kurtosis
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -45,14 +44,26 @@ def increments(inp, scale: int = 10):
     else:
         data = inp.data
 
-    delta_inp = np.abs((data[scale:, :] - data[:-scale, :]))
+    delta_inp = data[scale:, :] - data[:-scale, :]
 
     result = np.array(delta_inp)
 
-    time, cols = [inp.coords[dim].data for dim in inp.dims]
+    cols = [inp.coords[dim].data for dim in inp.dims]
 
-    result = xr.DataArray(result, coords=[time[0:len(delta_inp)], cols],
-                          dims=inp.dims, attrs=inp.attrs)
+    if inp.data.ndim == 1:
+        result = xr.DataArray(
+            np.squeeze(result),
+            coords=[cols[0][0 : len(delta_inp)]],
+            dims=inp.dims,
+            attrs=inp.attrs,
+        )
+    else:
+        result = xr.DataArray(
+            np.squeeze(result),
+            coords=[cols[0][0 : len(delta_inp)], *cols[1:]],
+            dims=inp.dims,
+            attrs=inp.attrs,
+        )
 
     kurt = kurtosis(result, axis=0, fisher=False)
 
