@@ -9,9 +9,9 @@ import numpy as np
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -19,7 +19,7 @@ def iso86012timevec(time):
     r"""Convert ISO 8601 time string into time vector.
 
     Parameters
-    ---------
+    ----------
     time : str
         Time in ISO 8601 format YYYY-MM-DDThh:mm:ss.mmmuuunnn.
 
@@ -34,10 +34,12 @@ def iso86012timevec(time):
 
     """
 
-    iso_8601 = r"(?P<years>[0-9]{4})-(?P<months>[0-9]{2})-(?P<days>[0-9]{2})" \
-               r"T(?P<hours>[0-9]{2}):(?P<minutes>[0-9]{2})" \
-               r":(?P<seconds>[0-9]{2}).(?P<miliseconds>[0-9]{3})" \
-               r"(?P<microseconds>[0-9]{3})(?P<nanoseconds>[0-9]{3})"
+    iso_8601 = (
+        r"(?P<years>[0-9]{4})-(?P<months>[0-9]{2})-(?P<days>[0-9]{2})"
+        r"T(?P<hours>[0-9]{2}):(?P<minutes>[0-9]{2})"
+        r":(?P<seconds>[0-9]{2}).(?P<miliseconds>[0-9]{3})"
+        r"(?P<microseconds>[0-9]{3})(?P<nanoseconds>[0-9]{3})"
+    )
 
     # Define parser
     fmt = re.compile(iso_8601)
