@@ -3,16 +3,15 @@
 
 # Local imports
 from ..mms import rotate_tensor
-
 from .norm import norm
 from .resample import resample
 from .ts_scalar import ts_scalar
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -21,7 +20,7 @@ def plasma_beta(b_xyz, p_xyz):
 
     .. math::
 
-        \\beta = \\frac{P_{th}}{P_b}
+        \beta = \frac{P_{th}}{P_b}
 
     where : :math:`P_b = B^2 / 2 \\mu_0`
 
