@@ -7,9 +7,9 @@ import xarray as xr
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -18,7 +18,7 @@ def pvi(inp, scale: int = 10):
 
     .. math::
 
-        y = \\frac{|x_i - x_{i+s}|^2}{<|x_i - x_{i+s}|^2>}
+        y = \frac{|x_i - x_{i+s}|^2}{<|x_i - x_{i+s}|^2>}
 
     where :math:`s` is the scale.
 
@@ -42,14 +42,18 @@ def pvi(inp, scale: int = 10):
         data = inp.data
 
     delta_inp = np.abs((data[scale:, :] - data[:-scale, :]))
-    delta_inp2 = np.sum(delta_inp ** 2, axis=1)
+    delta_inp2 = np.sum(delta_inp**2, axis=1)
     sigma = np.mean(delta_inp2)
     result = np.array(delta_inp2 / sigma)
 
     time = inp.coords[inp.dims[0]].data
 
-    result = xr.DataArray(result, coords=[time[0:len(delta_inp)]],
-                          dims=[inp.dims[0]], attrs=inp.attrs)
+    result = xr.DataArray(
+        result,
+        coords=[time[0 : len(delta_inp)]],
+        dims=[inp.dims[0]],
+        attrs=inp.attrs,
+    )
 
     result.attrs["units"] = "dimensionless"
 
