@@ -6,9 +6,9 @@ import numpy as np
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -35,8 +35,8 @@ def sph2cart(azimuth, elevation, r):
 
     """
 
-    x = r * np.cos(elevation) * np.cos(azimuth)
-    y = r * np.cos(elevation) * np.sin(azimuth)
-    z = r * np.sin(elevation)
+    x = r * np.sin(elevation) * np.cos(azimuth)
+    y = r * np.sin(elevation) * np.sin(azimuth)
+    z = r * np.cos(elevation)
 
     return x, y, z
