@@ -10,9 +10,9 @@ import xarray as xr
 
 __author__ = "Louis Richard"
 __email__ = "louisr@irfu.se"
-__copyright__ = "Copyright 2020-2021"
+__copyright__ = "Copyright 2020-2023"
 __license__ = "MIT"
-__version__ = "2.3.7"
+__version__ = "2.4.2"
 __status__ = "Prototype"
 
 
@@ -38,11 +38,14 @@ def t_eval(inp, times):
     for i, time in enumerate(times):
         idx[i] = bisect.bisect_left(inp.time.data, time)
 
-    idx = idx.astype(int)
+    idx = idx.astype(np.int64)
 
     if inp.ndim == 2:
-        out = xr.DataArray(inp.data[idx, :], coords=[times, inp.comp],
-                           dims=["time", "comp"])
+        out = xr.DataArray(
+            inp.data[idx, :],
+            coords=[times, inp.comp],
+            dims=["time", "comp"],
+        )
     else:
         out = xr.DataArray(inp.data[idx], coords=[times], dims=["time"])
 
